/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTBEGINCOMMITROLLBACK_H_
#define TESTBEGINCOMMITROLLBACK_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for Begin/Commit/Rollback commands.
 * Runs read and write requests inside transactions.
 * A controller *MUST* run locally for test success !!!
 */
class TestBeginCommitRollback : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /** Calls ConnectionSetup::setUp() then set connection autocommit=false */
  virtual void setUp();

  /**
   * Sends a read request and a checks that a commit won't raise an error
   */
  void testReadRequestAndCommit();
  /**
   * Sends a read request and a checks that a roolback won't raise an error
   */
  void testReadRequestAndRollback();
  /**
   * Sends a write request and a commit inside a transaction and checks that
   * the value has been written correctly.
   */
  void testWriteRequestAndCommit();
  /**
   * Sends a write request and a rollback inside a transaction and checks that
   * the value has not been written.
   */
  void testWriteRequestAndRollback();
};

#endif /*TESTBEGINCOMMITROLLBACK_H_*/
