/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTCONNECT_H_
#define TESTCONNECT_H_


#include <cppunit/TestFixture.h>
#include <cppunit/TestCase.h>
#include <cppunit/TestSuite.h>
#include <cppunit/TestCaller.h>

#include "Connection.hpp"

/**
 * Test class for connection establishement.
 * Tests connection establishment to bad address, bad port and finally to a
 * running controller. 
 * A controller *MUST* run locally for test success !!!
 */
class TestConnect : CppUnit::TestFixture
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /** Init connectionPtr to NULL */
  void setUp();
  /** Frees connectionPtr if applicable */
  void tearDown();
  /**
   * Tries to connect to a dummy controller address and checks that there is a
   * failure.
   */
  void testConnectBadAddress();
  /**
   * Tries to connect to a controller on a dummy port and checks that there is
   * a failure.
   */
  void testConnectBadPort();
  /**
   * Tries to connect to a controller on a dummy DB and checks that there is
   * a failure.
   */
  void testConnectBadDB();
  /**
   * Tries to connect to a controller with a dummy username and checks that the
   * correct exception is thrown.
   */
  void testConnectBadUser();
  /**
   * Tries to connect to a controller with a dummy password and checks that the
   * correct exception is thrown.
   */
  void testConnectBadPass();
  /**
   * Connects to a controller on a local machine (that must be running !) with
   * the default port and checks everything went good.
   */
  void testConnectGood();

private:
  CarobNS::Connection*       connectionPtr;
};

#endif /*TESTCONNECT_H_*/
