/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTCONTROLLERPOOL_H_
#define TESTCONTROLLERPOOL_H_


#include <cppunit/TestFixture.h>
#include <cppunit/TestCase.h>
#include <cppunit/TestSuite.h>
#include <cppunit/TestCaller.h>

#include "ControllerPool.hpp"

/**
 * Test class for controller connection policy
 * Tests suspected controller queuing and update
 * A controller *MUST* run locally for test success !!!
 */
class TestControllerPool : CppUnit::TestFixture
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /** Nothing to setup */
  void setUp();
  /** Nothing to tearDown */
  void tearDown();
  /**
   * Adds 2 out of 4 controllers to the list of suspects and checks that the
   * getController function returns the non suspect controller in the good order
   */
  void testRoundRobinSequence();
  /**
   * Adds all controllers to the list of suspects and checks that an error is
   * thrown when asking for another controller (NoMoreControllerException)
   */
  void testNoMoreController();
  /**
   * USER INTERACTION NEEDED !
   * Adds valid controllers to the list of suspects and checks that they come up
   * again. Note: this test needs 4 (basic) servers to run locally !!! (user
   * input is asked when servers are ready). These servers can be simulated by
   * Lenart Janos's socket utility ("socket -s <port>" command)
   * See http://packages.debian.org/stable/net/socket for more info
   */
  void testSuspectListUpdate();
private:
};

#endif /*TESTCONTROLLERPOOL_H_*/
