/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTFAILOVER_H_
#define TESTFAILOVER_H_


#include <cppunit/TestFixture.h>
#include <cppunit/TestCase.h>
#include <cppunit/TestSuite.h>
#include <cppunit/TestCaller.h>

#include "Connection.hpp"

/**
 * Test class for controller connection policy
 * Tests suspected controller queuing and update
 * A controller *MUST* run locally for test success !!!
 */
class TestFailOver : CppUnit::TestFixture
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /** Nothing to setup */
  void setUp();
  /** Nothing to tearDown */
  void tearDown();
  /**
   * Tries to connect to 1 then 2 failing controllers (actually with dummy ports)
   */
  void testReconnectNoControllers();
  /**
   * Tries to connect to a list of controller in which only 1 ctrller is up
   */
  void testConnectOnlyOneControllerUp();
  /**
   * USER INTERACTION NEEDED !
   * Launches 1000 write requests having 2 controllers.
   * During these writes, the user has to stop one of the controllers and check
   * that the other one is connected to silently
   * Stop controller preferably with iptables. Command for iptables:
   * > iptables -A INPUT -i lo -p tcp --dport 25322 -d localhost -j REJECT --reject-with tcp-reset
   * to restore traffic:
   * > iptables -D INPUT 1
   */
  void testReconnect();
private:
};

#endif /*TESTFAILOVER_H_*/
