/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTBIGDECIMAL_H_
#define TESTBIGDECIMAL_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for Statement class.
 * This is basically a copy of exec read and exec write commands testing
 * A controller *MUST* run locally for test success !!!
 */
class TestBigDecimal : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /**
   * After calling ConnectionSetup::setUp(), writes a bunch of big decimal
   * values in a table that will be read by all tests
   */
  virtual void setUp();

  /**
   * Read big decimal values using getAsString() and given locale, then checks
   * the read and written values are consistent
   */
  void testGetAsString(const std::locale& loc);
  /**
   * @see #testGetAsString(const std::locale& loc)
   */
  void testGetAsStringUsingCLocale();
  /**
   * @see #testGetAsString(const std::locale& loc)
   */
  void testGetAsStringUsingUserLocale();
  /**
   * @see #testGetAsString(const std::locale& loc)
   */
  void testGetAsStringUsingFrLocale();
  /**
   * @see #testGetAsString(const std::locale& loc)
   */
  void testGetAsStringUsingUSLocale();
  /**
   * Read big decimal values using getAsInt() and checks that the integer read
   * is the expected one
   */
  void testGetAsInt();
  /**
   * Read big decimal values using getAsInt64() and checks that the long long
   * read is the expected one
   */
  void testGetAsInt64();
  /**
   * Read big decimal values using getAsUInt64() and checks that the unsigned
   * long long read is the expected one
   */
  void testGetAsUInt64();
  /**
   * Read big decimal values using getAsFloat() and checks that the double read
   * is the expected one
   */
  void testGetAsFloat();
  /**
   * Read big decimal values using getAsDouble() and checks that the double read
   * is the expected one
   */
  void testGetAsDouble();
};

#endif /*TESTBIGDECIMAL_H_*/
