/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Zsolt Simon
 * Contributor(s): 
 */

#ifndef TESTPARAMETERSTATEMENT_H_
#define TESTPARAMETERSTATEMENT_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for Statement class.
 * This is basically a copy of exec read and exec write commands testing
 * A controller *MUST* run locally for test success !!!
 */
class TestParameterStatement : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  //EXECUTE QUERY
  /**
   * Tries to execute a query with not all params set
   */
  void testExecuteQueryLessParams();
  /**
   * Sends a valid select request to the controller via a Statement and checks
   * that there is no error. Also displays a part of the result for manual
   * checking.
   */
  void testExecuteQueryGood();
  
  //EXECUTE UPDATE
  /**
   * Tries to bind a parameter to a non existing one.
   * checks that the error is consistent.
   */
  void testExecuteUpdateBadParams();
  /**
   * Sends a valid update request to the controller via a Statement and checks
   * that there is no error.
   */
  void testExecuteUpdateGood();
  /**
   * Tests execute function with bad query of different forms (bad query, wrong
   * table)
   */
  void testExecuteBadRequests();
  /**
   * Tests execute function with a select statement
   */
  void testExecuteWithSelect();
  /**
   * Tests execute function with an update statement
   */
  void testExecuteWithUpdate();
  /**
   * Tests setBoolean function by sending a write request within a parameter
   * statement and checking that the value read back is the original one.
   */
  void testBoolean();
  /**
   * Tests setString function by sending a write request within a parameter
   * statement and checking that the value read back is the original one.
   */
  void testStrings();
  /**
   * Tests setBigDecimal function by sending a write request within a parameter
   * statement and checking that the value read back is the original one.
   */
  void testBigDecimal();
  /**
   * Tests setNull function
   */
  void testSetNull();
};

#endif /*TESTPARAMETERSTATEMENT_H_*/
