/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#include <cppunit/ui/text/TestRunner.h>
// For QT ui, replace the above line by this:
//#include <cppunit/ui/qt/TestRunner.h>
//#include <qt3/qapplication.h>

#include <cppunit/TestResult.h>
#include <cppunit/BriefTestProgressListener.h>

#include "CarobException.hpp"
#include "StringCodecs.hpp"
#include "Common.hpp"
#ifdef CAROB_USE_LOG4CXX
#include <log4cxx/logger.h>
#include <log4cxx/basicconfigurator.h>
#include <log4cxx/propertyconfigurator.h>
#endif

#include "CarobProtector.hpp"

#include "01-Unit/TestStringCodecs.hpp"
#include "10-Connection/TestConnect.hpp"
#include "10-Connection/TestControllerPool.hpp"
#include "10-Connection/TestFailOver.hpp"
#include "10-Connection/TestBeginCommitRollback.hpp"
#include "20-Write/TestExecWriteRequest.hpp"
#include "30-ResultSet/TestSimpleUnicode.hpp"
#include "30-ResultSet/TestExecReadRequest.hpp"
#include "30-ResultSet/TestDriverResultSet.hpp"
#include "30-ResultSet/TestBigDecimal.hpp"
#include "35-ResultList/TestExec.hpp"
#include "40-Parameter-PreparedStatement/TestParameterStatement.hpp"
#include "40-Parameter-PreparedStatement/TestPreparedStatement.hpp"
#include "40-Parameter-PreparedStatement/TestIEEE754.hpp"

using namespace CarobNS;

int main (int argc, char **argv)
{
#ifdef CAROB_USE_LOG4CXX
  // Set up a simple configuration that logs on the console.
  log4cxx::BasicConfigurator::configure();
#endif

	// Log Level:
  // available levels are found in log4cxx documentation
  // or in file include/Common.hpp
  //setLogLevel(LOG_LEVEL_DEBUG);
  setLogLevel(LOG_LEVEL_OFF);

#ifdef __MINGW32__
  //init windows socket lib
  WSADATA WSAData;
  if (isInfoEnabled())
    logInfo(L"Carob unit tests", L"Initializing windows socket library");
  if (WSAStartup(MAKEWORD(2,0), &WSAData) != 0)
  {
    if (isErrorEnabled())
      logError(L"read_example", L"Unable to find suitable windows socket library");
    throw ConnectionException(L"Unable to find suitable windows socket library");
    return false;
  }
#endif

  std::set_unexpected(UnexpectedException::convertUnexpected);
  CppUnit::TextUi::TestRunner runner;
  // For QT ui, replace the above line by this:
  //QApplication app(argc, argv);
  //CppUnit::QtUi::TestRunner runner;
  runner.addTest(TestConnect::suite());
  runner.addTest(TestExecWriteRequest::suite());
  runner.addTest(TestExecReadRequest::suite());
  runner.addTest(TestExec::suite());
  runner.addTest(TestBeginCommitRollback::suite());
  runner.addTest(TestBigDecimal::suite());
  runner.addTest(TestDriverResultSet::suite());
  runner.addTest(TestStringCodecs::suite());
  runner.addTest(TestSimpleUnicode::suite());
  runner.addTest(TestParameterStatement::suite());
  runner.addTest(TestIEEE754::suite());
  runner.addTest(TestControllerPool::suite());
  runner.addTest(TestFailOver::suite());

  // add our own protector
  CarobProtector* cprot = new CarobProtector();
  runner.eventManager().pushProtector(cprot);
  CppUnit::BriefTestProgressListener listener;
  runner.eventManager().addListener( &listener );

  // To run only one test:
  //runner.run("TestBigDecimal");
  runner.run();
  //Do *NOT* delete CarobProtector, it is done by the ProtectorChain (in pop())
#ifdef __MINGW32__
  WSACleanup();
#endif
  return 0;

}

